@@ -149,7 +149,7 @@ class SqliteConnection : public DbConnection
 
 
 #ifdef USE_MYSQL
-typedef struct st_mysql MYSQL;
+typedef struct MYSQL_STRUCT MYSQL;
 
 class MySqlConnection : public DbConnection
 {
