@@ -42,14 +42,14 @@ AMAROK_EXPORT_PLUGIN( IpodMediaDevice )
 #include <metadata/tplugins.h>
 #include <hintlineedit.h>
 
-#include <kactionclasses.h>
-#include <kapplication.h>
+#include <tdeactionclasses.h>
+#include <tdeapplication.h>
 #include <kmountpoint.h>
 #include <kpushbutton.h>
 #include <kprogress.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 #include <kiconloader.h>
-#include <kpopupmenu.h>
+#include <tdepopupmenu.h>
 
 #include <tqcheckbox.h>
 #include <tqdir.h>
@@ -277,17 +277,17 @@ IpodMediaDevice::IpodMediaDevice()
     m_syncStatsCheck = 0;
     m_autoDeletePodcastsCheck = 0;
 
-    KActionCollection *ac = new KActionCollection( this );
-    KActionMenu *am = new KActionMenu( i18n( "iPod" ), Amarok::icon( "device" ), ac );
+    TDEActionCollection *ac = new TDEActionCollection( this );
+    TDEActionMenu *am = new TDEActionMenu( i18n( "iPod" ), Amarok::icon( "device" ), ac );
     m_customAction = am;
     m_customAction->setEnabled( false );
     am->setDelayed( false );
-    KPopupMenu *menu = am->popupMenu();
+    TDEPopupMenu *menu = am->popupMenu();
     connect( menu, TQT_SIGNAL(activated(int)), TQT_SLOT(slotIpodAction(int)) );
     menu->insertItem( i18n( "Stale and Orphaned" ), CHECK_INTEGRITY );
     menu->insertItem( i18n( "Update Artwork" ), UPDATE_ARTWORK );
 
-    KPopupMenu *ipodGen = new KPopupMenu( menu );
+    TDEPopupMenu *ipodGen = new TDEPopupMenu( menu );
     menu->insertItem( i18n( "Set iPod Model" ), ipodGen );
     const Itdb_IpodInfo *table = itdb_info_get_ipod_info_table();
     if( !table )
@@ -299,7 +299,7 @@ IpodMediaDevice::IpodMediaDevice()
     {
         const Itdb_IpodInfo *info = table;
         infoFound = false;
-        KPopupMenu *gen = 0;
+        TDEPopupMenu *gen = 0;
         int index = SET_IPOD_MODEL;
         while( info->model_number )
         {
@@ -308,7 +308,7 @@ IpodMediaDevice::IpodMediaDevice()
                 if (!infoFound)
                 {
                     infoFound = true;
-                    gen = new KPopupMenu( ipodGen );
+                    gen = new TDEPopupMenu( ipodGen );
                     connect( gen, TQT_SIGNAL(activated(int)), TQT_SLOT(slotIpodAction(int)) );
                     ipodGen->insertItem(
                             itdb_info_get_ipod_generation_string( info->ipod_generation),
@@ -999,7 +999,7 @@ IpodMediaDevice::createLockFile( bool silent )
         if( !silent )
         {
             if( KMessageBox::warningContinueCancel( m_parent, msg, i18n( "Remove iTunes Lock File?" ),
-                        KGuiItem(i18n("&Remove"), "editdelete"), TQString(), KMessageBox::Dangerous )
+                        KGuiItem(i18n("&Remove"), "edit-delete"), TQString(), KMessageBox::Dangerous )
                     == KMessageBox::Continue )
             {
                 msg = i18n( "Media Device: removing lockfile %1 failed: %2. " )
@@ -2197,7 +2197,7 @@ IpodMediaDevice::removeDBTrack(Itdb_Track *track)
 }
 
 bool
-IpodMediaDevice::getCapacity( KIO::filesize_t *total, KIO::filesize_t *available )
+IpodMediaDevice::getCapacity( TDEIO::filesize_t *total, TDEIO::filesize_t *available )
 {
     if(!m_itdb)
         return false;
@@ -2215,8 +2215,8 @@ IpodMediaDevice::getCapacity( KIO::filesize_t *total, KIO::filesize_t *available
         return false;
     }
 
-    *total = buf.f_blocks * (KIO::filesize_t)buf.f_frsize;
-    *available = buf.f_bavail * (KIO::filesize_t)buf.f_frsize;
+    *total = buf.f_blocks * (TDEIO::filesize_t)buf.f_frsize;
+    *available = buf.f_bavail * (TDEIO::filesize_t)buf.f_frsize;
 
     return *total > 0;
 #else
@@ -2231,7 +2231,7 @@ IpodMediaDevice::rmbPressed( TQListViewItem* qitem, const TQPoint& point, int )
     bool locked = m_mutex.locked();
 
     KURL::List urls = m_view->nodeBuildDragList( 0 );
-    KPopupMenu menu( m_view );
+    TDEPopupMenu menu( m_view );
 
     enum Actions { CREATE_PLAYLIST, APPEND, LOAD, QUEUE,
         COPY_TO_COLLECTION,
@@ -2241,7 +2241,7 @@ IpodMediaDevice::rmbPressed( TQListViewItem* qitem, const TQPoint& point, int )
         DELETE_PLAYED, DELETE_FROM_IPOD, REMOVE_FROM_PLAYLIST,
         FIRST_PLAYLIST};
 
-    KPopupMenu *playlistsMenu = 0;
+    TDEPopupMenu *playlistsMenu = 0;
     if ( item )
     {
         if( item->type() == MediaItem::PLAYLISTSROOT )
@@ -2261,19 +2261,19 @@ IpodMediaDevice::rmbPressed( TQListViewItem* qitem, const TQPoint& point, int )
         switch( item->type() )
         {
         case MediaItem::ARTIST:
-            menu.insertItem( SmallIconSet( Amarok::icon( "cdrom_unmount" ) ), i18n( "Burn All Tracks by This Artist" ), BURN_ARTIST );
+            menu.insertItem( SmallIconSet( Amarok::icon( "media-optical-cdrom" ) ), i18n( "Burn All Tracks by This Artist" ), BURN_ARTIST );
             menu.setItemEnabled( BURN_ARTIST, K3bExporter::isAvailable() );
             break;
 
         case MediaItem::ALBUM:
-            menu.insertItem( SmallIconSet( Amarok::icon( "cdrom_unmount" ) ), i18n( "Burn This Album" ), BURN_ALBUM );
+            menu.insertItem( SmallIconSet( Amarok::icon( "media-optical-cdrom" ) ), i18n( "Burn This Album" ), BURN_ALBUM );
             menu.setItemEnabled( BURN_ALBUM, K3bExporter::isAvailable() );
             break;
 
         default:
-            menu.insertItem( SmallIconSet( Amarok::icon( "cdrom_unmount" ) ), i18n( "Burn to CD as Data" ), BURN_DATACD );
+            menu.insertItem( SmallIconSet( Amarok::icon( "media-optical-cdrom" ) ), i18n( "Burn to CD as Data" ), BURN_DATACD );
             menu.setItemEnabled( BURN_DATACD, K3bExporter::isAvailable() );
-            menu.insertItem( SmallIconSet( Amarok::icon( "cdaudio_unmount" ) ), i18n( "Burn to CD as Audio" ), BURN_AUDIOCD );
+            menu.insertItem( SmallIconSet( Amarok::icon( "media-optical-cdaudio" ) ), i18n( "Burn to CD as Audio" ), BURN_AUDIOCD );
             menu.setItemEnabled( BURN_AUDIOCD, K3bExporter::isAvailable() );
             break;
         }
@@ -2303,7 +2303,7 @@ IpodMediaDevice::rmbPressed( TQListViewItem* qitem, const TQPoint& point, int )
                 menu.insertItem( SmallIconSet( Amarok::icon( "playlist" ) ), i18n( "Make Media Device Playlist" ), MAKE_PLAYLIST );
                 menu.setItemEnabled( MAKE_PLAYLIST, !locked );
 
-                playlistsMenu = new KPopupMenu(&menu);
+                playlistsMenu = new TDEPopupMenu(&menu);
                 int i=0;
                 for(MediaItem *it = dynamic_cast<MediaItem *>(m_playlistItem->firstChild());
                         it;
@@ -2673,7 +2673,7 @@ IpodMediaDevice::pathExists( const TQString &ipodPath, TQString *realPath )
 }
 
 void
-IpodMediaDevice::fileDeleted( KIO::Job *job )  //SLOT
+IpodMediaDevice::fileDeleted( TDEIO::Job *job )  //SLOT
 {
     if(job->error())
     {
@@ -2688,9 +2688,9 @@ IpodMediaDevice::deleteFile( const KURL &url )
 {
     debug() << "deleting " << url.prettyURL() << endl;
     m_waitForDeletion = true;
-    KIO::Job *job = KIO::file_delete( url, false );
-    connect( job, TQT_SIGNAL( result( KIO::Job * ) ),
-            this,  TQT_SLOT( fileDeleted( KIO::Job * ) ) );
+    TDEIO::Job *job = TDEIO::file_delete( url, false );
+    connect( job, TQT_SIGNAL( result( TDEIO::Job * ) ),
+            this,  TQT_SLOT( fileDeleted( TDEIO::Job * ) ) );
     do
     {
         kapp->processEvents( 100 );
