@@ -17,7 +17,7 @@ namespace Amarok
     class PluginConfig : public TQObject
     {
         Q_OBJECT
-  TQ_OBJECT
+  
 
         signals:
             /** Emit whenever some view setting is changed by the user */
@@ -39,7 +39,7 @@ namespace Amarok
             virtual bool isDefault() const = 0;
 
         public slots:
-            /** Save view state using, eg KConfig */
+            /** Save view state using, eg TDEConfig */
             virtual void save() = 0;
     };
 }
